import { defineComponent, computed, createBlock, openBlock, unref, mergeProps, withCtx, renderSlot } from 'vue';
import { useAccordionContext } from './use-accordion-context.js';
import * as collapsible from '../collapsible/collapsible.js';
import '@zag-js/color-picker';
import '@zag-js/date-picker';
import '@internationalized/date';
import { useForwardExpose } from '../../utils/use-forward-expose.js';
import { createSplitProps } from '../create-split-props.js';
import { useAccordionItemPropsContext } from './use-accordion-item-props-context.js';

const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "accordion-item-content",
  props: {
    asChild: { type: Boolean }
  },
  setup(__props) {
    const splitVisibilityProps = createSplitProps();
    const accordion = useAccordionContext();
    const itemProps = useAccordionItemPropsContext();
    const itemContentProps = computed(() => {
      const contentProps = accordion.value.getItemContentProps(itemProps);
      const [, ownProps] = splitVisibilityProps(contentProps, ["hidden", "data-state"]);
      return ownProps;
    });
    useForwardExpose();
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(collapsible).Content, mergeProps(itemContentProps.value, { "as-child": _ctx.asChild }), {
        default: withCtx(() => [
          renderSlot(_ctx.$slots, "default")
        ]),
        _: 3
      }, 16, ["as-child"]);
    };
  }
});

export { _sfc_main as default };
