import { defineComponent, computed, createBlock, openBlock, unref, mergeProps, withCtx, renderSlot } from 'vue';
import { useRenderStrategyProps } from '../../utils/use-render-strategy.js';
import { useForwardExpose } from '../../utils/use-forward-expose.js';
import * as collapsible from '../collapsible/collapsible.js';
import { useAccordionContext } from './use-accordion-context.js';
import { AccordionItemProvider } from './use-accordion-item-context.js';
import { AccordionItemPropsProvider } from './use-accordion-item-props-context.js';

const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "accordion-item",
  props: {
    value: {},
    disabled: { type: Boolean },
    asChild: { type: Boolean }
  },
  setup(__props) {
    const accordion = useAccordionContext();
    const props = __props;
    const item = computed(() => accordion.value.getItemState(props));
    const renderStrategyProps = useRenderStrategyProps();
    const itemContentProps = computed(() => accordion.value.getItemContentProps(props));
    AccordionItemProvider(item);
    AccordionItemPropsProvider(props);
    useForwardExpose();
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(collapsible).Root, mergeProps(unref(accordion).getItemProps(props), {
        open: item.value.expanded,
        "lazy-mount": unref(renderStrategyProps).lazyMount,
        "unmount-on-exit": unref(renderStrategyProps).unmountOnExit,
        ids: { content: itemContentProps.value.id }
      }), {
        default: withCtx(() => [
          renderSlot(_ctx.$slots, "default")
        ]),
        _: 3
      }, 16, ["open", "lazy-mount", "unmount-on-exit", "ids"]);
    };
  }
});

export { _sfc_main as default };
