import * as accordion from '@zag-js/accordion';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';

const useAccordion = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const context = computed(() => {
    const localeProps = toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      onFocusChange: (details) => emit?.("focusChange", details),
      value: localeProps.modelValue,
      ...cleanProps(localeProps),
      onValueChange: (details) => {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localeProps?.onValueChange?.(details);
      }
    };
  });
  const service = useMachine(accordion.machine, context);
  return computed(() => accordion.connect(service, normalizeProps));
};

export { useAccordion };
