import * as angleSlider from '@zag-js/angle-slider';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';

const useAngleSlider = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const context = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      dir: locale?.value.dir,
      getRootNode: env?.value.getRootNode,
      value: localProps.modelValue,
      ...cleanProps(localProps),
      onValueChange: (details) => {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localProps.onValueChange?.(details);
      },
      onValueChangeEnd: (details) => {
        emit?.("valueChangeEnd", details);
        localProps.onValueChangeEnd?.(details);
      }
    };
  });
  const service = useMachine(angleSlider.machine, context);
  return computed(() => angleSlider.connect(service, normalizeProps));
};

export { useAngleSlider };
