import * as avatar from '@zag-js/avatar';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';

const useAvatar = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const context = computed(() => {
    const localeProps = toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localeProps),
      onStatusChange: (details) => {
        emit?.("statusChange", details);
        localeProps.onStatusChange?.(details);
      }
    };
  });
  const service = useMachine(avatar.machine, context);
  return computed(() => avatar.connect(service, normalizeProps));
};

export { useAvatar };
