import * as carousel from '@zag-js/carousel';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';

const useCarousel = (props, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const context = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onAutoplayStatusChange: (details) => {
        emit?.("autoplayStatusChange", details);
        localProps.onAutoplayStatusChange?.(details);
      },
      onDragStatusChange: (details) => {
        emit?.("dragStatusChange", details);
        localProps.onDragStatusChange?.(details);
      },
      onPageChange: (details) => {
        emit?.("pageChange", details);
        emit?.("update:page", details.page);
        localProps.onPageChange?.(details);
      }
    };
  });
  const service = useMachine(carousel.machine, context);
  return computed(() => carousel.connect(service, normalizeProps));
};

export { useCarousel };
