import * as checkbox from '@zag-js/checkbox';
import { mergeProps, useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';
import { useFieldContext } from '../field/use-field-context.js';
import { useCheckboxGroupContext } from './use-checkbox-group-context.js';

const useCheckbox = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const field = useFieldContext();
  const checkboxGroup = useCheckboxGroupContext();
  const computedProps = computed(() => {
    const propsValue = toValue(props);
    return mergeProps(propsValue, checkboxGroup?.value.getItemProps({ value: propsValue.value }) ?? {});
  });
  const context = computed(() => {
    const localProps = toValue(computedProps);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        hiddenInput: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      readOnly: field?.value.readOnly,
      invalid: field?.value.invalid,
      required: field?.value.required,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onCheckedChange(details) {
        emit?.("checkedChange", details);
        emit?.("update:checked", details.checked);
        localProps.onCheckedChange?.(details);
      }
    };
  });
  const service = useMachine(checkbox.machine, context);
  return computed(() => checkbox.connect(service, normalizeProps));
};

export { useCheckbox };
