'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const collapsible = require('@zag-js/collapsible');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const collapsible__namespace = /*#__PURE__*/_interopNamespaceDefault(collapsible);

const useCollapsible = (props = {}, emits) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const context = vue.computed(() => {
    const localeProps = vue.toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localeProps),
      onExitComplete: () => {
        emits?.("exitComplete");
        localeProps.onExitComplete?.();
      },
      onOpenChange: (details) => {
        emits?.("openChange", details);
        emits?.("update:open", details.open);
        localeProps.onOpenChange?.(details);
      }
    };
  });
  const service = vue$1.useMachine(collapsible__namespace.machine, context);
  const api = vue.computed(() => collapsible__namespace.connect(service, vue$1.normalizeProps));
  const wasVisible = vue.ref(false);
  vue.watch(
    () => api.value.visible,
    () => {
      if (api.value.visible) {
        wasVisible.value = true;
      }
    }
  );
  return vue.computed(() => {
    const localeProps = vue.toValue(props);
    return {
      ...api.value,
      unmounted: !api.value.visible && !wasVisible.value && localeProps.lazyMount || localeProps.unmountOnExit && !api.value.visible && wasVisible.value
    };
  });
};

exports.useCollapsible = useCollapsible;
