import * as colorPicker from '@zag-js/color-picker';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';
import { useFieldContext } from '../field/use-field-context.js';

const useColorPicker = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const field = useFieldContext();
  const context = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        input: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      invalid: field?.value.invalid,
      readOnly: field?.value.readOnly,
      required: field?.value.required,
      dir: locale.value.dir,
      value: localProps.modelValue,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onOpenChange(details) {
        emit?.("openChange", details);
        emit?.("update:open", details.open);
        localProps.onOpenChange?.(details);
      },
      onValueChange(details) {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localProps.onValueChange?.(details);
      },
      onFocusOutside: (details) => {
        emit?.("focusOutside", details);
        localProps.onFocusOutside?.(details);
      },
      onFormatChange: (details) => {
        emit?.("formatChange", details);
        emit?.("update:format", details.format);
        localProps.onFormatChange?.(details);
      },
      onInteractOutside: (details) => {
        emit?.("interactOutside", details);
        localProps.onInteractOutside?.(details);
      },
      onPointerDownOutside: (details) => {
        emit?.("pointerDownOutside", details);
        localProps.onPointerDownOutside?.(details);
      },
      onValueChangeEnd: (details) => {
        emit?.("valueChangeEnd", details);
        localProps.onValueChangeEnd?.(details);
      }
    };
  });
  const service = useMachine(colorPicker.machine, context);
  return computed(() => colorPicker.connect(service, normalizeProps));
};

export { useColorPicker };
