'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const combobox = require('@zag-js/combobox');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');
const useFieldContext = require('../field/use-field-context.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const combobox__namespace = /*#__PURE__*/_interopNamespaceDefault(combobox);

const useCombobox = (props, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const field = useFieldContext.useFieldContext();
  const context = vue.computed(() => {
    const localeProps = vue.toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        input: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      readOnly: field?.value.readOnly,
      required: field?.value.required,
      invalid: field?.value.invalid,
      dir: locale.value.dir,
      value: localeProps.modelValue,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localeProps),
      onFocusOutside: (details) => {
        emit?.("focusOutside", details);
        localeProps.onFocusOutside?.(details);
      },
      onHighlightChange: (details) => {
        emit?.("highlightChange", details);
        emit?.("update:highlightedValue", details.highlightedValue);
        localeProps.onHighlightChange?.(details);
      },
      onInputValueChange: (details) => {
        emit?.("inputValueChange", details);
        emit?.("update:inputValue", details.inputValue);
        localeProps.onInputValueChange?.(details);
      },
      onInteractOutside: (details) => {
        emit?.("interactOutside", details);
        localeProps.onInteractOutside?.(details);
      },
      onPointerDownOutside: (details) => {
        emit?.("pointerDownOutside", details);
        localeProps.onPointerDownOutside?.(details);
      },
      onOpenChange: (details) => {
        emit?.("openChange", details);
        emit?.("update:open", details.open);
        localeProps.onOpenChange?.(details);
      },
      onValueChange: (details) => {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localeProps.onValueChange?.(details);
      }
    };
  });
  const service = vue$1.useMachine(combobox__namespace.machine, context);
  return vue.computed(() => combobox__namespace.connect(service, vue$1.normalizeProps));
};

exports.useCombobox = useCombobox;
