import * as combobox from '@zag-js/combobox';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';
import { useFieldContext } from '../field/use-field-context.js';

const useCombobox = (props, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const field = useFieldContext();
  const context = computed(() => {
    const localeProps = toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        input: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      readOnly: field?.value.readOnly,
      required: field?.value.required,
      invalid: field?.value.invalid,
      dir: locale.value.dir,
      value: localeProps.modelValue,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localeProps),
      onFocusOutside: (details) => {
        emit?.("focusOutside", details);
        localeProps.onFocusOutside?.(details);
      },
      onHighlightChange: (details) => {
        emit?.("highlightChange", details);
        emit?.("update:highlightedValue", details.highlightedValue);
        localeProps.onHighlightChange?.(details);
      },
      onInputValueChange: (details) => {
        emit?.("inputValueChange", details);
        emit?.("update:inputValue", details.inputValue);
        localeProps.onInputValueChange?.(details);
      },
      onInteractOutside: (details) => {
        emit?.("interactOutside", details);
        localeProps.onInteractOutside?.(details);
      },
      onPointerDownOutside: (details) => {
        emit?.("pointerDownOutside", details);
        localeProps.onPointerDownOutside?.(details);
      },
      onOpenChange: (details) => {
        emit?.("openChange", details);
        emit?.("update:open", details.open);
        localeProps.onOpenChange?.(details);
      },
      onValueChange: (details) => {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localeProps.onValueChange?.(details);
      }
    };
  });
  const service = useMachine(combobox.machine, context);
  return computed(() => combobox.connect(service, normalizeProps));
};

export { useCombobox };
