import { defineComponent, computed, createBlock, openBlock, unref, mergeProps, withCtx, renderSlot } from 'vue';
import { ark } from '../factory.js';
import { useDatePickerContext } from './use-date-picker-context.js';
import { useDatePickerTableCellPropsContext } from './use-date-picker-table-cell-props-context.js';
import { useDatePickerViewPropsContext } from './use-date-picker-view-props-context.js';
import { useForwardExpose } from '../../utils/use-forward-expose.js';

const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "date-picker-table-cell-trigger",
  props: {
    asChild: { type: Boolean }
  },
  setup(__props) {
    const datePicker = useDatePickerContext();
    const cellProps = useDatePickerTableCellPropsContext();
    const viewProps = useDatePickerViewPropsContext();
    const triggerProps = computed(() => {
      const viewMap = {
        day: datePicker.value.getDayTableCellTriggerProps,
        month: datePicker.value.getMonthTableCellTriggerProps,
        year: datePicker.value.getYearTableCellTriggerProps
      };
      const viewFn = viewMap[viewProps.view];
      return viewFn(cellProps);
    });
    useForwardExpose();
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(ark).div, mergeProps(triggerProps.value, { "as-child": _ctx.asChild }), {
        default: withCtx(() => [
          renderSlot(_ctx.$slots, "default")
        ]),
        _: 3
      }, 16, ["as-child"]);
    };
  }
});

export { _sfc_main as default };
