'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const datePicker = require('@zag-js/date-picker');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const datePicker__namespace = /*#__PURE__*/_interopNamespaceDefault(datePicker);

const useDatePicker = (props = {}, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const context = vue.computed(() => {
    const localeProps = vue.toValue(props);
    return {
      id,
      dir: locale.value.dir,
      locale: locale.value.locale,
      value: localeProps.modelValue,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localeProps),
      onFocusChange: (details) => {
        emit?.("focusChange", details);
        emit?.("update:focusedValue", details.focusedValue);
        localeProps.onFocusChange?.(details);
      },
      onViewChange: (details) => {
        emit?.("viewChange", details);
        emit?.("update:view", details.view);
        localeProps.onViewChange?.(details);
      },
      onOpenChange: (details) => {
        emit?.("openChange", details);
        emit?.("update:open", details.open);
        localeProps.onOpenChange?.(details);
      },
      onValueChange: (details) => {
        emit?.("valueChange", details);
        console.log("valueChange", details);
        emit?.("update:modelValue", details.value);
        localeProps.onValueChange?.(details);
      }
    };
  });
  const service = vue$1.useMachine(datePicker__namespace.machine, context);
  return vue.computed(() => datePicker__namespace.connect(service, vue$1.normalizeProps));
};

exports.useDatePicker = useDatePicker;
