'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const fileUpload = require('@zag-js/file-upload');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');
const useFieldContext = require('../field/use-field-context.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const fileUpload__namespace = /*#__PURE__*/_interopNamespaceDefault(fileUpload);

const useFileUpload = (props = {}, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const field = useFieldContext.useFieldContext();
  const context = vue.computed(() => {
    const localeProps = vue.toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        hiddenInput: field?.value.ids.control
      },
      dir: locale.value.dir,
      disabled: field?.value.disabled,
      invalid: field?.value.invalid,
      locale: locale.value.locale,
      required: field?.value.required,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localeProps),
      onFileChange: (details) => {
        emit?.("fileChange", details);
        localeProps.onFileChange?.(details);
      },
      onFileAccept: (details) => {
        emit?.("fileAccept", details);
        localeProps.onFileAccept?.(details);
      },
      onFileReject: (details) => {
        emit?.("fileReject", details);
        localeProps.onFileReject?.(details);
      }
    };
  });
  const service = vue$1.useMachine(fileUpload__namespace.machine, context);
  return vue.computed(() => fileUpload__namespace.connect(service, vue$1.normalizeProps));
};

exports.useFileUpload = useFileUpload;
