import * as fileUpload from '@zag-js/file-upload';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';
import { useFieldContext } from '../field/use-field-context.js';

const useFileUpload = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const field = useFieldContext();
  const context = computed(() => {
    const localeProps = toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        hiddenInput: field?.value.ids.control
      },
      dir: locale.value.dir,
      disabled: field?.value.disabled,
      invalid: field?.value.invalid,
      locale: locale.value.locale,
      required: field?.value.required,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localeProps),
      onFileChange: (details) => {
        emit?.("fileChange", details);
        localeProps.onFileChange?.(details);
      },
      onFileAccept: (details) => {
        emit?.("fileAccept", details);
        localeProps.onFileAccept?.(details);
      },
      onFileReject: (details) => {
        emit?.("fileReject", details);
        localeProps.onFileReject?.(details);
      }
    };
  });
  const service = useMachine(fileUpload.machine, context);
  return computed(() => fileUpload.connect(service, normalizeProps));
};

export { useFileUpload };
