import * as floatingPanel from '@zag-js/floating-panel';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';

const useFloatingPanel = (props = {}, emit) => {
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const id = useId();
  const machineProps = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      dir: locale?.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onOpenChange: (details) => {
        emit?.("openChange", details);
        emit?.("update:open", details.open);
        localProps.onOpenChange?.(details);
      },
      onSizeChange(details) {
        emit?.("sizeChange", details);
        emit?.("update:size", details.size);
        localProps.onSizeChange?.(details);
      },
      onPositionChange(details) {
        emit?.("positionChange", details);
        emit?.("update:position", details.position);
        localProps.onPositionChange?.(details);
      },
      onPositionChangeEnd(details) {
        emit?.("positionChangeEnd", details);
        localProps.onPositionChangeEnd?.(details);
      },
      onSizeChangeEnd(details) {
        emit?.("sizeChangeEnd", details);
        localProps.onSizeChangeEnd?.(details);
      },
      onStageChange(details) {
        emit?.("stageChange", details);
        localProps.onStageChange?.(details);
      }
    };
  });
  const service = useMachine(floatingPanel.machine, machineProps);
  return computed(() => floatingPanel.connect(service, normalizeProps));
};

export { useFloatingPanel };
