'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const hoverCard = require('@zag-js/hover-card');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const hoverCard__namespace = /*#__PURE__*/_interopNamespaceDefault(hoverCard);

const useHoverCard = (props = {}, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const context = vue.computed(() => {
    const localeProps = vue.toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localeProps),
      onOpenChange: (details) => {
        emit?.("openChange", details);
        emit?.("update:open", details.open);
        localeProps.onOpenChange?.(details);
      },
      onFocusOutside: (details) => {
        emit?.("focusOutside", details);
        localeProps.onFocusOutside?.(details);
      },
      onInteractOutside: (details) => {
        emit?.("interactOutside", details);
        localeProps.onInteractOutside?.(details);
      },
      onPointerDownOutside: (details) => {
        emit?.("pointerDownOutside", details);
        localeProps.onPointerDownOutside?.(details);
      }
    };
  });
  const service = vue$1.useMachine(hoverCard__namespace.machine, context);
  return vue.computed(() => hoverCard__namespace.connect(service, vue$1.normalizeProps));
};

exports.useHoverCard = useHoverCard;
