'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const listbox = require('@zag-js/listbox');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const listbox__namespace = /*#__PURE__*/_interopNamespaceDefault(listbox);

const useListbox = (props, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const context = vue.computed(() => {
    const localProps = vue.toValue(props);
    return {
      id,
      dir: locale.value.dir,
      value: localProps.modelValue,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localProps),
      onValueChange: (details) => {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localProps.onValueChange?.(details);
      },
      onHighlightChange: (details) => {
        emit?.("highlightChange", details);
        localProps.onHighlightChange?.(details);
      },
      onSelect: (details) => {
        emit?.("select", details);
        localProps.onSelect?.(details);
      }
    };
  });
  const service = vue$1.useMachine(listbox__namespace.machine, context);
  return vue.computed(() => listbox__namespace.connect(service, vue$1.normalizeProps));
};

exports.useListbox = useListbox;
