'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const menu = require('@zag-js/menu');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const menu__namespace = /*#__PURE__*/_interopNamespaceDefault(menu);

const useMenu = (props = {}, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const context = vue.computed(() => {
    const localeProps = vue.toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localeProps),
      onOpenChange: (details) => {
        emit?.("openChange", details);
        emit?.("update:open", details.open);
        localeProps.onOpenChange?.(details);
      },
      onEscapeKeyDown: (details) => {
        emit?.("escapeKeyDown", details);
        localeProps.onEscapeKeyDown?.(details);
      },
      onFocusOutside: (details) => {
        emit?.("focusOutside", details);
        localeProps.onFocusOutside?.(details);
      },
      onHighlightChange: (details) => {
        emit?.("highlightChange", details);
        emit?.("update:highlightedValue", details.highlightedValue);
        localeProps.onHighlightChange?.(details);
      },
      onInteractOutside: (details) => {
        emit?.("interactOutside", details);
        localeProps.onInteractOutside?.(details);
      },
      onPointerDownOutside: (details) => {
        emit?.("pointerDownOutside", details);
        localeProps.onPointerDownOutside?.(details);
      },
      onSelect: (details) => {
        emit?.("select", details);
        localeProps.onSelect?.(details);
      }
    };
  });
  const machine = vue$1.useMachine(menu__namespace.machine, context);
  const api = vue.computed(() => menu__namespace.connect(machine, vue$1.normalizeProps));
  return {
    api,
    machine
  };
};

exports.useMenu = useMenu;
