'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const numberInput = require('@zag-js/number-input');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');
const useFieldContext = require('../field/use-field-context.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const numberInput__namespace = /*#__PURE__*/_interopNamespaceDefault(numberInput);

const useNumberInput = (props = {}, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const field = useFieldContext.useFieldContext();
  const context = vue.computed(() => {
    const localeProps = vue.toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        input: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      readOnly: field?.value.readOnly,
      required: field?.value.required,
      invalid: field?.value.invalid,
      dir: locale.value.dir,
      locale: locale.value.locale,
      value: localeProps.modelValue,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localeProps),
      onValueChange: (details) => {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localeProps.onValueChange?.(details);
      },
      onFocusChange: (details) => {
        emit?.("focusChange", details);
        localeProps.onFocusChange?.(details);
      },
      onValueInvalid: (details) => {
        emit?.("valueInvalid", details);
        localeProps.onValueInvalid?.(details);
      }
    };
  });
  const service = vue$1.useMachine(numberInput__namespace.machine, context);
  return vue.computed(() => numberInput__namespace.connect(service, vue$1.normalizeProps));
};

exports.useNumberInput = useNumberInput;
