import * as pagination from '@zag-js/pagination';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';

const usePagination = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const context = computed(() => {
    const localeProps = toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localeProps),
      onPageChange: (details) => {
        emit?.("pageChange", details);
        emit?.("update:page", details.page);
        localeProps.onPageChange?.(details);
      },
      onPageSizeChange: (details) => {
        emit?.("pageSizeChange", details);
        emit?.("update:pageSize", details.pageSize);
        localeProps.onPageSizeChange?.(details);
      }
    };
  });
  const service = useMachine(pagination.machine, context);
  return computed(() => pagination.connect(service, normalizeProps));
};

export { usePagination };
