import * as pinInput from '@zag-js/pin-input';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';
import { useFieldContext } from '../field/use-field-context.js';

const usePinInput = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const field = useFieldContext();
  const context = computed(() => {
    const localeProps = toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        hiddenInput: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      readOnly: field?.value.readOnly,
      required: field?.value.required,
      invalid: field?.value.invalid,
      dir: locale.value.dir,
      value: localeProps.modelValue,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localeProps),
      onValueChange: (details) => {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localeProps.onValueChange?.(details);
      },
      onValueComplete: (details) => {
        emit?.("valueComplete", details);
        localeProps.onValueComplete?.(details);
      },
      onValueInvalid: (details) => {
        emit?.("valueInvalid", details);
        localeProps.onValueInvalid?.(details);
      }
    };
  });
  const service = useMachine(pinInput.machine, context);
  return computed(() => pinInput.connect(service, normalizeProps));
};

export { usePinInput };
