import * as select from '@zag-js/select';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';
import { useFieldContext } from '../field/use-field-context.js';

const useSelect = (props, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const field = useFieldContext();
  const context = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        hiddenSelect: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      readOnly: field?.value.readOnly,
      invalid: field?.value.invalid,
      required: field?.value.required,
      dir: locale.value.dir,
      value: localProps.modelValue,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onValueChange: (details) => {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localProps.onValueChange?.(details);
      },
      onHighlightChange: (details) => {
        emit?.("highlightChange", details);
        emit?.("update:highlightedValue", details.highlightedValue);
        localProps.onHighlightChange?.(details);
      },
      onOpenChange: (details) => {
        emit?.("openChange", details);
        emit?.("update:open", details.open);
        localProps.onOpenChange?.(details);
      },
      onFocusOutside: (details) => {
        emit?.("focusOutside", details);
        localProps.onFocusOutside?.(details);
      },
      onInteractOutside: (details) => {
        emit?.("interactOutside", details);
        localProps.onInteractOutside?.(details);
      },
      onPointerDownOutside: (details) => {
        emit?.("pointerDownOutside", details);
        localProps.onPointerDownOutside?.(details);
      }
    };
  });
  const service = useMachine(select.machine, context);
  return computed(() => select.connect(service, normalizeProps));
};

export { useSelect };
