'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const signaturepad = require('@zag-js/signature-pad');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');
const useFieldContext = require('../field/use-field-context.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const signaturepad__namespace = /*#__PURE__*/_interopNamespaceDefault(signaturepad);

const useSignaturePad = (props = {}, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const field = useFieldContext.useFieldContext();
  const context = vue.computed(() => {
    const localProps = vue.toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        hiddenInput: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      readOnly: field?.value.readOnly,
      required: field?.value.required,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localProps),
      onDraw: (details) => {
        emit?.("draw", details);
        localProps.onDraw?.(details);
      },
      onDrawEnd: (details) => {
        emit?.("drawEnd", details);
        localProps.onDrawEnd?.(details);
      }
    };
  });
  const service = vue$1.useMachine(signaturepad__namespace.machine, context);
  return vue.computed(() => signaturepad__namespace.connect(service, vue$1.normalizeProps));
};

exports.useSignaturePad = useSignaturePad;
