import * as signaturepad from '@zag-js/signature-pad';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';
import { useFieldContext } from '../field/use-field-context.js';

const useSignaturePad = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const field = useFieldContext();
  const context = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        hiddenInput: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      readOnly: field?.value.readOnly,
      required: field?.value.required,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onDraw: (details) => {
        emit?.("draw", details);
        localProps.onDraw?.(details);
      },
      onDrawEnd: (details) => {
        emit?.("drawEnd", details);
        localProps.onDrawEnd?.(details);
      }
    };
  });
  const service = useMachine(signaturepad.machine, context);
  return computed(() => signaturepad.connect(service, normalizeProps));
};

export { useSignaturePad };
