import * as slider from '@zag-js/slider';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';

const useSlider = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const context = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      dir: locale.value.dir,
      value: localProps.modelValue,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onFocusChange: (details) => {
        emit?.("focusChange", details);
        localProps.onFocusChange?.(details);
      },
      onValueChangeEnd: (details) => {
        emit?.("valueChangeEnd", details);
        localProps.onValueChangeEnd?.(details);
      },
      onValueChange: (details) => {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localProps.onValueChange?.(details);
      }
    };
  });
  const service = useMachine(slider.machine, context);
  return computed(() => slider.connect(service, normalizeProps));
};

export { useSlider };
