'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const splitter = require('@zag-js/splitter');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const splitter__namespace = /*#__PURE__*/_interopNamespaceDefault(splitter);

const useSplitter = (props, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const context = vue.computed(() => {
    const localProps = vue.toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localProps),
      onResize: (details) => {
        emit?.("resize", details);
        emit?.("update:size", details.size);
        localProps.onResize?.(details);
      },
      onResizeEnd: (details) => {
        emit?.("resizeEnd", details);
        localProps.onResizeEnd?.(details);
      },
      onCollapse: (details) => {
        emit?.("collapse", details);
        localProps.onCollapse?.(details);
      },
      onExpand: (details) => {
        emit?.("expand", details);
        localProps.onExpand?.(details);
      },
      onResizeStart() {
        emit?.("resizeStart");
        localProps.onResizeStart?.();
      }
    };
  });
  const service = vue$1.useMachine(splitter__namespace.machine, context);
  return vue.computed(() => splitter__namespace.connect(service, vue$1.normalizeProps));
};

exports.useSplitter = useSplitter;
