import * as splitter from '@zag-js/splitter';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';

const useSplitter = (props, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const context = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onResize: (details) => {
        emit?.("resize", details);
        emit?.("update:size", details.size);
        localProps.onResize?.(details);
      },
      onResizeEnd: (details) => {
        emit?.("resizeEnd", details);
        localProps.onResizeEnd?.(details);
      },
      onCollapse: (details) => {
        emit?.("collapse", details);
        localProps.onCollapse?.(details);
      },
      onExpand: (details) => {
        emit?.("expand", details);
        localProps.onExpand?.(details);
      },
      onResizeStart() {
        emit?.("resizeStart");
        localProps.onResizeStart?.();
      }
    };
  });
  const service = useMachine(splitter.machine, context);
  return computed(() => splitter.connect(service, normalizeProps));
};

export { useSplitter };
