'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const zagSwitch = require('@zag-js/switch');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');
const useFieldContext = require('../field/use-field-context.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const zagSwitch__namespace = /*#__PURE__*/_interopNamespaceDefault(zagSwitch);

const useSwitch = (props = {}, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const field = useFieldContext.useFieldContext();
  const context = vue.computed(() => {
    const localProps = vue.toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        hiddenInput: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      readOnly: field?.value.readOnly,
      invalid: field?.value.invalid,
      required: field?.value.required,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localProps),
      onCheckedChange(details) {
        emit?.("checkedChange", details);
        emit?.("update:checked", details.checked);
        localProps.onCheckedChange?.(details);
      }
    };
  });
  const service = vue$1.useMachine(zagSwitch__namespace.machine, context);
  return vue.computed(() => zagSwitch__namespace.connect(service, vue$1.normalizeProps));
};

exports.useSwitch = useSwitch;
