import * as tagsInput from '@zag-js/tags-input';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';
import { useFieldContext } from '../field/use-field-context.js';

const useTagsInput = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const field = useFieldContext();
  const context = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      ids: {
        label: field?.value.ids.label,
        hiddenInput: field?.value.ids.control
      },
      disabled: field?.value.disabled,
      invalid: field?.value.invalid,
      readOnly: field?.value.readOnly,
      required: field?.value.required,
      dir: locale.value.dir,
      value: localProps.modelValue,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onValueChange: (details) => {
        emit?.("valueChange", details);
        emit?.("update:modelValue", details.value);
        localProps.onValueChange?.(details);
      },
      onFocusOutside: (details) => {
        emit?.("focusOutside", details);
        localProps.onFocusOutside?.(details);
      },
      onHighlightChange: (details) => {
        emit?.("highlightChange", details);
        localProps.onHighlightChange?.(details);
      },
      onInputValueChange: (details) => {
        emit?.("inputValueChange", details);
        emit?.("update:inputValue", details.inputValue);
        localProps.onInputValueChange?.(details);
      },
      onInteractOutside: (details) => {
        emit?.("interactOutside", details);
        localProps.onInteractOutside?.(details);
      },
      onPointerDownOutside: (details) => {
        emit?.("pointerDownOutside", details);
        localProps.onPointerDownOutside?.(details);
      },
      onValueInvalid: (details) => {
        emit?.("valueInvalid", details);
        localProps.onValueInvalid?.(details);
      }
    };
  });
  const service = useMachine(tagsInput.machine, context);
  return computed(() => tagsInput.connect(service, normalizeProps));
};

export { useTagsInput };
