import * as timer from '@zag-js/timer';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { cleanProps } from '../../utils/clean-props.js';

const useTimer = (props, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const context = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onComplete: () => {
        emit?.("complete");
        localProps.onComplete?.();
      },
      onTick: (details) => {
        emit?.("tick", details);
        localProps.onTick?.(details);
      }
    };
  });
  const service = useMachine(timer.machine, context);
  return computed(() => timer.connect(service, normalizeProps));
};

export { useTimer };
