import * as tour from '@zag-js/tour';
import { useMachine, normalizeProps } from '@zag-js/vue';
import { useId, computed, toValue } from 'vue';
import { useEnvironmentContext } from '../../providers/environment/use-environment-context.js';
import { useLocaleContext, DEFAULT_LOCALE } from '../../providers/locale/use-locale-context.js';
import { cleanProps } from '../../utils/clean-props.js';

const useTour = (props = {}, emit) => {
  const id = useId();
  const env = useEnvironmentContext();
  const locale = useLocaleContext(DEFAULT_LOCALE);
  const context = computed(() => {
    const localProps = toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps(localProps),
      onFocusOutside: (details) => {
        emit?.("focusOutside", details);
        localProps.onFocusOutside?.(details);
      },
      onInteractOutside: (details) => {
        emit?.("interactOutside", details);
        localProps.onInteractOutside?.(details);
      },
      onPointerDownOutside: (details) => {
        emit?.("pointerDownOutside", details);
        localProps.onPointerDownOutside?.(details);
      },
      onStatusChange: (details) => {
        emit?.("statusChange", details);
        localProps.onStatusChange?.(details);
      },
      onStepChange: (details) => {
        emit?.("stepChange", details);
        localProps.onStepChange?.(details);
      },
      onStepsChange(details) {
        emit?.("stepsChange", details);
        localProps.onStepsChange?.(details);
      }
    };
  });
  const service = useMachine(tour.machine, context);
  return computed(() => tour.connect(service, normalizeProps));
};

export { useTour };
