'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const treeView = require('@zag-js/tree-view');
const vue$1 = require('@zag-js/vue');
const vue = require('vue');
const useEnvironmentContext = require('../../providers/environment/use-environment-context.cjs');
const useLocaleContext = require('../../providers/locale/use-locale-context.cjs');
const cleanProps = require('../../utils/clean-props.cjs');

function _interopNamespaceDefault(e) {
  const n = Object.create(null, { [Symbol.toStringTag]: { value: 'Module' } });
  if (e) {
    for (const k in e) {
      if (k !== 'default') {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}

const treeView__namespace = /*#__PURE__*/_interopNamespaceDefault(treeView);

const useTreeView = (props, emit) => {
  const id = vue.useId();
  const env = useEnvironmentContext.useEnvironmentContext();
  const locale = useLocaleContext.useLocaleContext(useLocaleContext.DEFAULT_LOCALE);
  const context = vue.computed(() => {
    const localeProps = vue.toValue(props);
    return {
      id,
      dir: locale.value.dir,
      getRootNode: env?.value.getRootNode,
      ...cleanProps.cleanProps(localeProps),
      onFocusChange: (details) => {
        emit?.("focusChange", details);
        emit?.("update:focusedValue", details.focusedValue);
        localeProps.onFocusChange?.(details);
      },
      onExpandedChange: (details) => {
        emit?.("expandedChange", details);
        emit?.("update:expandedValue", details.expandedValue);
        localeProps.onExpandedChange?.(details);
      },
      onSelectionChange: (details) => {
        emit?.("selectionChange", details);
        emit?.("update:selectedValue", details.selectedValue);
        localeProps.onSelectionChange?.(details);
      }
    };
  });
  const service = vue$1.useMachine(treeView__namespace.machine, context);
  return vue.computed(() => treeView__namespace.connect(service, vue$1.normalizeProps));
};

exports.useTreeView = useTreeView;
